@@ -1,6 +1,6 @@
 import unittest
 import torch as T
-from lpd.metrics import BinaryAccuracy, BinaryAccuracyWithLogits, CategoricalAccuracy, CategoricalAccuracyWithLogits
+from lpd.metrics import BinaryAccuracy, BinaryAccuracyWithLogits, CategoricalAccuracy, CategoricalAccuracyWithLogits, TopKCategoricalAccuracy
 
 class TestMetrics(unittest.TestCase):
 
@@ -91,3 +91,42 @@ class TestMetrics(unittest.TestCase):
         y_true = T.Tensor([0,1,2])
         self.assertEqual(metric(y_pred, y_true), 0.0)
 
+    def test_top_k_categorical_accuracy(self):
+        # K = 1
+        metric = TopKCategoricalAccuracy(k=1)
+
+        y_pred = T.Tensor([[0.1, 0.9, 0.8], [0.05, 0.95, 0], [0.05, 0.95, 0]])
+        y_true = T.Tensor([1,1,1])
+        self.assertEqual(metric(y_pred, y_true), 1.0)
+
+        y_pred = T.Tensor([[0.1, 0.9, 0.5], [0.05, 0.8, 0.]])
+        y_true = T.Tensor([2,1])
+        self.assertEqual(metric(y_pred, y_true), 0.5)
+
+        y_pred = T.Tensor([[0.1, 0.3, 0.8], [0.05, 0.2, 0.3], [0.8, 0.4, 0.3]])
+        y_true = T.Tensor([1,1,0])
+        self.assertEqual(metric(y_pred, y_true), 1/3)
+
+        y_pred = T.Tensor([[0.1, 0.3, 0.8], [0.05, 0.2, 0.3], [0.8, 0.4, 0.3], [0.8, 0.4, 0.3]])
+        y_true = T.Tensor([1,1,0,2])
+        self.assertEqual(metric(y_pred, y_true), 0.25)
+
+
+        # K = 2
+        metric = TopKCategoricalAccuracy(k=2)
+
+        y_pred = T.Tensor([[0.1, 0.9, 0.8], [0.05, 0.95, 0], [0.05, 0.95, 0]])
+        y_true = T.Tensor([1,1,1])
+        self.assertEqual(metric(y_pred, y_true), 1.0)
+
+        y_pred = T.Tensor([[0.1, 0.9, 0.01], [0.05, 0.8, 0.]])
+        y_true = T.Tensor([2,1])
+        self.assertEqual(metric(y_pred, y_true), 0.5)
+
+        y_pred = T.Tensor([[0.1, 0.3, 0.8], [0.05, 0.2, 0.3], [0.3, 0.4, 0.8]])
+        y_true = T.Tensor([1,1,0])
+        self.assertEqual(metric(y_pred, y_true), 2/3)
+
+        y_pred = T.Tensor([[0.3, 0.1, 0.8], [0.5, 0.2, 0.3], [0.8, 0.4, 0.3], [0.8, 0.4, 0.3]])
+        y_true = T.Tensor([1,1,0,2])
+        self.assertEqual(metric(y_pred, y_true), 0.25)
\ No newline at end of file
